Filling

Enum Filling 

pub enum Filling {
    Spaces(usize),
    Text(String),
    Tabs {
        spaces: usize,
        tab_size: usize,
    },
}
The text to put in between each pair of columns.

This does not include any spaces used when aligning cells.

Variants



Spaces(usize)

A number of spaces



Text(String)

An arbitrary string

"|" is a common choice.



Tabs

Fill spaces with \t

Fields

spaces: usize

A number of spaces

tab_size: usize

Size of \t in spaces